OrchestratorResult class

Summary of the results produced by a test generation run.

Constructors

OrchestratorResult({required int featuresScanned, required int filesWritten, required int filesSkipped, required List<String> errors})
Creates a result summary.
const

Properties

errors List<String>
Errors encountered during generation.
final
featuresScanned int
Number of features scanned.
final
filesSkipped int
Number of files skipped because dry-run mode was active.
final
filesWritten int
Number of files successfully written.
final
hasErrors bool
Returns true when the run produced one or more errors.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited